import React, { useContext, useEffect, useState } from 'react'
import AppContext from 'src/context/AppContext'

const ProtectedUi = ({ role, view = true, onlyAdmin = false, children }) => {
  const [show, setShow] = useState(false)
  const { permissions, user, logout } = useContext(AppContext)

  useEffect(() => {
    if (user?.is_superuser) {
      setShow(true)
    } else {
      if (onlyAdmin) {
        if (!user?.user?.is_admin) {
          if (view) {
            setShow(false)
          } else {
            logout()
          }
        } else {
          setShow(true)
        }
      } else {
        if (permissions?.includes(role)) {
          setShow(true)
        } else {
          if (!view) {
            logout()
          } else {
            setShow(false)
          }
        }
      }
    }
  }, [role, view, onlyAdmin, permissions])

  return show && <>{children}</>
}

export default ProtectedUi
